regulators: Convert to new SensorType enumeration

There are several types of voltage regulator sensors, such as vout,
iout, and temperature.

The sensor types were previously defined by the enumeration
pmbus_utils::SensorValueType.  This enumeration should not have been
placed in the pmbus_utils namespace because it is not specific to PMBus.

A new enumeration with the simpler name SensorType was created in
sensors.hpp in a previous commit.

Remove the old enumeration from pmbus_utils.  Convert affected files to
use the new enumeration.

Signed-off-by: Shawn McCarney <shawnmm@us.ibm.com>
Change-Id: I4136b392b104edd3eee41ec29c779ad084c7c4de
diff --git a/phosphor-regulators/src/config_file_parser.hpp b/phosphor-regulators/src/config_file_parser.hpp
index 4b39b7e..63dcfd6 100644
--- a/phosphor-regulators/src/config_file_parser.hpp
+++ b/phosphor-regulators/src/config_file_parser.hpp
@@ -39,6 +39,7 @@
 #include "rule.hpp"
 #include "run_rule_action.hpp"
 #include "sensor_monitoring.hpp"
+#include "sensors.hpp"
 #include "set_device_action.hpp"
 
 #include <nlohmann/json.hpp>
@@ -684,17 +685,16 @@
     parseSensorMonitoring(const nlohmann::json& element);
 
 /**
  * Parses a JSON element containing a SensorValueType expressed as a string.
  *
  * Returns the corresponding SensorValueType enum value.
  *
  * Throws an exception if parsing fails.
  *
  * @param element JSON element
  * @return SensorValueType enum value
  */
-pmbus_utils::SensorValueType
-    parseSensorValueType(const nlohmann::json& element);
+SensorType parseSensorType(const nlohmann::json& element);
 
 /**
  * Parses a JSON element containing a set_device action.
@@ -684,17 +685,16 @@
 
 /**
- * Parses a JSON element containing a SensorValueType expressed as a string.
+ * Parses a JSON element containing a SensorType expressed as a string.
  *
@@ -684,17 +685,16 @@
  *
- * Returns the corresponding SensorValueType enum value.
+ * Returns the corresponding SensorType enum value.
  *
  * Throws an exception if parsing fails.
@@ -684,17 +685,16 @@
  *
  * @param element JSON element
- * @return SensorValueType enum value
+ * @return SensorType enum value
  */